@@ -5,7 +5,8 @@ echo "" 												>> $EXTENSION/build_order.txt
 export KF6_PREFIX=/opt/kf6
 
 # Required
-[[ $(command -v checkXML6) == "" ]] && echo "Installing kde_framework" && extension --install kde_framework && echo "Finished kde_framework"
+[ ! -d /opt/kf6 ] && echo "Installing kde_framework" && extension --install kde_framework && echo "Finished kde_framework"
+#[ ! -d /opt/kf6-6.14.0 ] && echo "Installing kde_framework:6.14.0" && extension --install kde_framework:6.14.0 && echo "Finished kde_framework:6.14.0"
 # Recommended
 if [[ $INSTALL_RECOMMENDED != false ]]; then 
 	[ ! -f /lib/libvulkan.so ] && echo "Installing vulkan_loader" && extension --install vulkan_loader && echo "Finished vulkan_loader"
